.. redirect-from:: /users/prev_whats_new/github_stats_3.4.0

.. _github-stats-3-4-0:

GitHub statistics for 3.4.0 (Mar 26, 2021)
==========================================

GitHub statistics for 2020/07/16 (tag: v3.3.0) - 2021/03/26

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 204 issues and merged 772 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/53?closed=1>`__

The following 177 authors contributed 3852 commits.

* A N U S H
* Adam Brown
* Aditya Malhotra
* aflah02
* Aitik Gupta
* Alejandro García
* Alex Henrie
* Alexander Schlüter
* Alexis de Almeida Coutinho
* Andreas C Mueller
* andrzejnovak
* Antony Lee
* Arthur Milchior
* bakes
* BAKEZQ
* BaoGiang HoangVu
* Ben Root
* BH4
* Bradley Dice
* Braxton Lamey
* Brian McFee
* Bruno Beltran
* Bryan Kok
* Byron Boulton
* Carsten Schelp
* ceelo777
* Charles
* CharlesHe16
* Christian Baumann
* Contextualist
* DangoMelon
* Daniel
* Daniel Ingram
* David Meyer
* David Stansby
* David Young
* deep-jkl
* Diego Leal
* Dr. Thomas A Caswell
* Dylan Cutler
* Eben Pendleton
* EBenkler
* ebenp
* ecotner
* Elliott Sales de Andrade
* Emily FY
* Eric Firing
* Eric Larson
* Eric Prestat
* Erik Benkler
* Evan Berkowitz
* Ewan Sutherland
* Federico Ariza
* Forrest
* Frank Sauerburger
* FrankTheCodeMonkey
* Greg Lucas
* hannah
* Harry Knight
* Harsh Sharma
* Hassan Kibirige
* Hugo van Kemenade
* Iain-S
* Ian Hunt-Isaak
* Ian Thomas
* ianhi
* Ilya V. Schurov
* ImportanceOfBeingErnest
* Isuru Fernando
* ItsRLuo
* J\. Scott Berg
* Jae-Joon Lee
* Jakub Klus
* Janakarajan Natarajan
* Jann Paul Mattern
* jbhopkins
* jeetvora331
* Jerome F. Villegas
* Jerome Villegas
* jfbu
* Jirka Hladky
* Jody Klymak
* Johan von Forstner
* johan12345
* john imperial
* John Losito
* John Peloquin
* johnthagen
* Jouni K. Seppänen
* Kate Perkins
* kate-perkins
* katrielester
* kolibril13
* kwgchi
* Lee Johnston
* Leo Singer
* linchiwei123
* Lucy Liu
* luz paz
* luzpaz
* Léonard Gérard
* majorwitty
* mansoor96g
* Maria Ilie
* Maria-Alexandra Ilie
* Marianne Corvellec
* Mark Harfouche
* Martin Spacek
* Mary Chris Go
* Matthew Petroff
* Matthias Bussonnier
* Matthias Geier
* Max Chen
* McToel
* Michael Grupp
* Michaël Defferrard
* Mihai Anton
* Mohammad Aflah Khan
* Neilzon Viloria
* neok-m4700
* Nora Moseman
* Pamela Wu
* pankajchetry1168
* Petar Mlinarić
* Peter Williams
* Phil Nagel
* philip-sparks
* Philipp Arras
* Philipp Nagel
* Pratyush Raj
* Péter Leéh
* rajpratyush
* Randall Ung
* reshamas
* Rezangyal
* Richard Sheridan
* richardsheridan
* Rob McDonald
* Rohit Rawat
* Ruben Verweij
* Ruth Comer
* Ryan May
* Sam Tygier
* shawnchen
* shawnchen1996
* ShawnChen1996
* Sidharth Bansal
* Srihitha Maryada
* Stephen Sinclair
* Struan Murray
* Theodor Athanasiadis
* Thomas A Caswell
* Thorvald Johannessen
* Tim Gates
* Tim Hoffmann
* Tobias Hangleiter
* tohc1
* Tom Charrett
* Tom Neep
* Tomas Fiers
* ulijh
* Ulrich J. Herter
* Utkarshp1
* Uwe F. Mayer
* Valentin Valls
* Vincent Cuenca
* Vineyard
* Vlas Sokolov
* Xianxiang Li
* xlilos
* Ye Chang
* Yichao Yu
* yozhikoff
* Yun Liu
* z0rgy
* zitorelova

GitHub issues and pull requests:

Pull Requests (772):

* :ghpull:`19775`: Fix deprecation for imread on URLs.
* :ghpull:`19772`: Backport PR #19535 on branch v3.4.x (Fix example's BasicUnit array conversion.)
* :ghpull:`19771`: Backport PR #19757 on branch v3.4.x (Fixed python -mpip typo)
* :ghpull:`19770`: Backport PR #19739 on branch v3.4.x (Changed 'python -mpip' to 'python -m pip' for consistency)
* :ghpull:`19535`: Fix example's BasicUnit array conversion.
* :ghpull:`19767`: Backport PR #19766 on branch v3.4.x (Set colormap modification removal to 3.6.)
* :ghpull:`19766`: Set colormap modification removal to 3.6.
* :ghpull:`19764`: Backport PR #19762 on branch v3.4.x (FIX: do not report that webagg supports blitting)
* :ghpull:`19762`: FIX: do not report that webagg supports blitting
* :ghpull:`19689`: Prepare API docs for v3.4.0
* :ghpull:`19761`: Backport PR #19746 on branch v3.4.x (Fix resizing in nbAgg.)
* :ghpull:`19746`: Fix resizing in nbAgg.
* :ghpull:`19757`: Fixed python -mpip typo
* :ghpull:`19739`: Changed 'python -mpip' to 'python -m pip' for consistency
* :ghpull:`19713`: DOC: Prepare What's new page for 3.4.0.
* :ghpull:`19742`: Backport PR #19741 on branch v3.4.x (Only override pickradius when picker is not a bool.)
* :ghpull:`19741`: Only override pickradius when picker is not a bool.
* :ghpull:`19726`: Backport PR #19505 on branch v3.4.x (Move some advanced documentation away from Installation Guide)
* :ghpull:`19505`: Move some advanced documentation away from Installation Guide
* :ghpull:`19712`: Backport PR #19707 on branch v3.4.x (DOC: fix dx in Arrow guide)
* :ghpull:`19711`: Backport PR #19709 on branch v3.4.x (Fix arrow_guide.py typo)
* :ghpull:`19709`: Fix arrow_guide.py typo
* :ghpull:`19707`: DOC: fix dx in Arrow guide
* :ghpull:`19699`: Backport PR #19695 on branch v3.4.x (DOC: Increase size of headings)
* :ghpull:`19695`: DOC: Increase size of headings
* :ghpull:`19697`: Backport PR #19690 on branch v3.4.x (Only warn about existing redirects if content differs.)
* :ghpull:`19690`: Only warn about existing redirects if content differs.
* :ghpull:`19696`: Backport PR #19665 on branch v3.4.x (Changed FormatStrFormatter documentation to include how to get unicode minus)
* :ghpull:`19680`: Backport PR #19402 on branch v3.4.x (Build aarch64 wheels)
* :ghpull:`19678`: Backport PR #19671 on branch v3.4.x (Fix crash in early window raise in gtk3.)
* :ghpull:`19671`: Fix crash in early window raise in gtk3.
* :ghpull:`19665`: Changed FormatStrFormatter documentation to include how to get unicode minus
* :ghpull:`19402`: Build aarch64 wheels
* :ghpull:`19669`: Backport PR #19661 on branch v3.4.x (Fix CoC link)
* :ghpull:`19668`: Backport PR #19663 on branch v3.4.x (ENH: add a copy method to colormaps)
* :ghpull:`19663`: ENH: add a copy method to colormaps
* :ghpull:`19661`: Fix CoC link
* :ghpull:`19652`: Backport PR #19649 on branch v3.4.x (Use globals() instead of locals() for adding colormaps as names to cm module)
* :ghpull:`19649`: Use globals() instead of locals() for adding colormaps as names to cm module
* :ghpull:`19651`: Backport PR #19618 on branch v3.4.x (FIX: make the cache in font_manager._get_font keyed by thread id)
* :ghpull:`19650`: Backport PR #19625 on branch v3.4.x (Restore _AxesStack to track a Figure's Axes order.)
* :ghpull:`19647`: Backport PR #19645 on branch v3.4.x (Fix comment in RectangleSelector)
* :ghpull:`19618`: FIX: make the cache in font_manager._get_font keyed by thread id
* :ghpull:`19648`: Backport PR #19643 on branch v3.4.x (Don't turn check_for_pgf into public API.)
* :ghpull:`19625`: Restore _AxesStack to track a Figure's Axes order.
* :ghpull:`19643`: Don't turn check_for_pgf into public API.
* :ghpull:`19645`: Fix comment in RectangleSelector
* :ghpull:`19644`: Backport PR #19611 on branch v3.4.x (Fix double picks.)
* :ghpull:`19611`: Fix double picks.
* :ghpull:`19640`: Backport PR #19639 on branch v3.4.x (FIX: do not allow single element list of str in subplot_mosaic)
* :ghpull:`19639`: FIX: do not allow single element list of str in subplot_mosaic
* :ghpull:`19638`: Backport PR #19632 on branch v3.4.x (Fix handling of warn keyword in Figure.show.)
* :ghpull:`19637`: Backport PR #19582 on branch v3.4.x (Add kerning to single-byte strings in PDFs)
* :ghpull:`19632`: Fix handling of warn keyword in Figure.show.
* :ghpull:`19582`: Add kerning to single-byte strings in PDFs
* :ghpull:`19629`: Backport PR #19548 on branch v3.4.x (Increase tolerances for other arches.)
* :ghpull:`19630`: Backport PR #19596 on branch v3.4.x (Fix for issue 17769: wx interactive figure close cause crash)
* :ghpull:`19596`: Fix for issue 17769: wx interactive figure close cause crash
* :ghpull:`19548`: Increase tolerances for other arches.
* :ghpull:`19616`: Backport PR #19577 on branch v3.4.x (Fix "return"->"enter" mapping in key names.)
* :ghpull:`19617`: Backport PR #19571 on branch v3.4.x (Fail early when setting Text color to a non-colorlike.)
* :ghpull:`19615`: Backport PR #19583 on branch v3.4.x (FIX: check for a set during color conversion)
* :ghpull:`19614`: Backport PR #19597 on branch v3.4.x (Fix IPython import issue)
* :ghpull:`19613`: Backport PR #19546 on branch v3.4.x (Move unrendered README.wx to thirdpartypackages/index.rst.)
* :ghpull:`19583`: FIX: check for a set during color conversion
* :ghpull:`19597`: Fix IPython import issue
* :ghpull:`19571`: Fail early when setting Text color to a non-colorlike.
* :ghpull:`19595`: Backport PR #19589 on branch v3.4.x (Changes linestyle parameter of flierprops)
* :ghpull:`19577`: Fix "return"->"enter" mapping in key names.
* :ghpull:`19589`: Changes linestyle parameter of flierprops
* :ghpull:`19592`: Backport PR #19587 on branch v3.4.x (DOC: fix plot_date doc)
* :ghpull:`19587`: DOC: fix plot_date doc
* :ghpull:`19580`: Backport PR #19456 on branch v3.4.x (Doc implement reredirects)
* :ghpull:`19579`: Backport PR #19567 on branch v3.4.x (DOC: fix typos)
* :ghpull:`19456`: Doc implement reredirects
* :ghpull:`19567`: DOC: fix typos
* :ghpull:`19542`: Backport PR #19532 on branch v3.4.x (Add note on interaction between text wrapping and bbox_inches='tight')
* :ghpull:`19549`: Backport PR #19545 on branch v3.4.x (Replace references to pygtk by pygobject in docs.)
* :ghpull:`19546`: Move unrendered README.wx to thirdpartypackages/index.rst.
* :ghpull:`19545`: Replace references to pygtk by pygobject in docs.
* :ghpull:`19532`: Add note on interaction between text wrapping and bbox_inches='tight'
* :ghpull:`19541`: MAINT: fix typo from #19438
* :ghpull:`19480`: Fix CallbackRegistry memory leak
* :ghpull:`19539`: In scatter, fix single rgb edgecolors handling
* :ghpull:`19438`: FIX: restore creating new axes via plt.subplot with different kwargs
* :ghpull:`18436`: Sync 3D errorbar with 2D
* :ghpull:`19472`: Fix default label visibility for top-or-left-labeled shared subplots().
* :ghpull:`19496`: MNT: Restore auto-adding Axes3D to their parent figure on init
* :ghpull:`19533`: Clarify the animated property and reword blitting tutorial a bit
* :ghpull:`19146`: Fix #19128: webagg reports incorrect values for non-alphanumeric key events on non-qwerty keyboards
* :ghpull:`18068`: Add note on writing binary formats to stdout using savefig()
* :ghpull:`19507`: FIX: ensure we import when the user cwd does not exist
* :ghpull:`19413`: FIX: allow add option for Axes3D(fig)
* :ghpull:`19498`: Dedupe implementations of {XAxis,YAxis}._get_tick_boxes_siblings.
* :ghpull:`19502`: Prefer projection="polar" over polar=True.
* :ghpull:`18480`: Clarify color priorities in collections
* :ghpull:`19501`: Fix text position with usetex and xcolor
* :ghpull:`19460`: Implement angles for bracket arrow styles.
* :ghpull:`18408`: FIX/API: ``fig.canvas.draw`` always updates internal state
* :ghpull:`19504`: Remove remaining references to Travis CI
* :ghpull:`13358`: 3D margins consistency  for mplot3d (isometric projection)
* :ghpull:`19529`: Simplify checking for tex packages.
* :ghpull:`19516`: Ignore files from annotate coverage reports
* :ghpull:`19500`: Remove workaround for numpy<1.16, and update version check.
* :ghpull:`19518`: Skip setting up a tmpdir in tests that don't need one.
* :ghpull:`19514`: DOC: add fixed-aspect colorbar examples
* :ghpull:`19511`: Clarify axes.autolimit_mode rcParam.
* :ghpull:`19503`: Fix tight_layout() on "canvasless" figures.
* :ghpull:`19410`: Set the GTK background color to white.
* :ghpull:`19497`: Add overset/underset whatsnew entry
* :ghpull:`19490`: Fix error message in plt.close().
* :ghpull:`19461`: Move ToolManager warnings to rcParam validator
* :ghpull:`19488`: Prefer ``tr1-tr2`` to ``tr1+tr2.inverted()``.
* :ghpull:`19485`: fix regression of axline behavior with non-linear scales
* :ghpull:`19314`: Fix over/under mathtext symbols
* :ghpull:`19468`: Include tex output in pdf LatexError.
* :ghpull:`19478`: Fix trivial typo in error message.
* :ghpull:`19449`: Switch array-like (M, N) to (M, N) array-like.
* :ghpull:`19459`: Merge v3.3.4 into master
* :ghpull:`18746`: Make figure parameter optional when constructing canvases.
* :ghpull:`19455`: Add note that pyplot cannot be used for 3D.
* :ghpull:`19457`: Use absolute link for discourse
* :ghpull:`19440`: Slightly reorganize api docs.
* :ghpull:`19344`: Improvements to Docs for new contributors
* :ghpull:`19435`: Replace gtk3 deprecated APIs that have simple replacements.
* :ghpull:`19452`: Fix the docstring of draw_markers to match the actual behavior.
* :ghpull:`19448`: Remove unnecessary facecolor cache in Patch3D.
* :ghpull:`19396`: CI: remove win prerelease azure + add py39
* :ghpull:`19426`: Support empty stairs.
* :ghpull:`19399`: Fix empty Poly3DCollections
* :ghpull:`19416`: fixes TypeError constructor returned NULL in wayland session
* :ghpull:`19439`: Move cheatsheet focus to the cheatsheets away
* :ghpull:`19425`: Add units to bar_label padding documentation.
* :ghpull:`19422`: Style fixes to triintepolate docs.
* :ghpull:`19421`: Switch to documenting generic collections in lowercase.
* :ghpull:`19411`: DOC: fix incorrect parameter names
* :ghpull:`19387`: Fix CSS table header layout
* :ghpull:`18683`: Better document font.<generic-family> rcParams entries.
* :ghpull:`19418`: BF: DOCS: fix slash for windows in conf.py
* :ghpull:`18544`: REORG: JoinStyle and CapStyle classes
* :ghpull:`19415`: Make TaggedValue in basic_units a sequence
* :ghpull:`19412`: DOC: correct off by one indentation.
* :ghpull:`19407`: Improve doc of default labelpad.
* :ghpull:`19373`: test for align_ylabel bug with constrained_layout
* :ghpull:`19347`: os.environ-related cleanups.
* :ghpull:`19319`: DOC: make canonical version stable
* :ghpull:`19395`: wx: Use integers in more places
* :ghpull:`17850`: MNT: set the facecolor of nofill markers
* :ghpull:`19334`: Fix qt backend on mac big sur
* :ghpull:`19394`: Don't allow pyzmq 22.0.0 on AppVeyor.
* :ghpull:`19367`: Deprecate imread() reading from URLs
* :ghpull:`19341`: MarkerStyle is considered immutable
* :ghpull:`19337`: Move sphinx extension files into mpl-data.
* :ghpull:`19389`: Temporarily switch intersphinx to latest pytest.
* :ghpull:`19390`: Doc: Minor formatting
* :ghpull:`19383`: Always include sample_data in installs.
* :ghpull:`19378`: Modify indicate_inset default label value
* :ghpull:`19357`: Shorten/make more consistent the half-filled marker definitions.
* :ghpull:`18649`: Deprecate imread() reading from URLs
* :ghpull:`19370`: Force classic ("auto") date converter in classic style.
* :ghpull:`19364`: Fix trivial doc typos.
* :ghpull:`19359`: Replace use of pyplot with OO api in some examples
* :ghpull:`19342`: FIX: fix bbox_inches=tight and constrained layout bad interaction
* :ghpull:`19350`: Describe how to test regular installations of Matplotlib
* :ghpull:`19332`: Prefer concatenate to h/vstack in simple cases.
* :ghpull:`19340`: Remove the deprecated rcParams["datapath"].
* :ghpull:`19326`: Whitespace in Choosing Colormaps tutorial plots
* :ghpull:`16417`: Deprecate rcParams["datapath"] in favor of mpl.get_data_path().
* :ghpull:`19336`: Revert "Deprecate setting Line2D's pickradius via set_picker."
* :ghpull:`19153`: MNT: Remove deprecated axes kwargs collision detection (version 2)
* :ghpull:`19330`: Remove register storage class from Agg files.
* :ghpull:`19324`: Improve FT2Font docstrings.
* :ghpull:`19328`: Explain annotation behavior when used in conjunction with arrows
* :ghpull:`19329`: Fix building against system qhull
* :ghpull:`19331`: Skip an ImageMagick test if ffmpeg is unavailable.
* :ghpull:`19333`: Fix PGF with special character paths.
* :ghpull:`19322`: Improve docs of _path C-extension.
* :ghpull:`19317`: Pin to oldest supported PyQt on minver CI instance.
* :ghpull:`19315`: Update the markers part of matplotlib.pyplot.plot document (fix issue #19274)
* :ghpull:`18978`: API: Remove deprecated axes kwargs collision detection
* :ghpull:`19306`: Fix some packaging issues
* :ghpull:`19291`: Cleanup code for format processing
* :ghpull:`19316`: Simplify X11 checking for Qt.
* :ghpull:`19287`: Speedup LinearSegmentedColormap.from_list.
* :ghpull:`19293`: Fix some docstring interpolations
* :ghpull:`19313`: Add missing possible return value to docs of get_verticalalignment()
* :ghpull:`18916`: Add overset and underset support for mathtext
* :ghpull:`18126`: FIX: Allow deepcopy on norms and scales
* :ghpull:`19281`: Make all transforms copiable (and thus scales, too).
* :ghpull:`19294`: Deprecate project argument to Line3DCollection.draw.
* :ghpull:`19307`: DOC: remove stray assignment in "multiple legends" example
* :ghpull:`19303`: Extended the convolution filter for correct dilation
* :ghpull:`19261`: Add machinery for png-only, single-font mathtext tests.
* :ghpull:`16571`: Update Qhull to 2019.1 reentrant version
* :ghpull:`16720`: Download qhull at build-or-sdist time.
* :ghpull:`18653`: ENH: Add func norm
* :ghpull:`19272`: Strip irrelevant information from testing docs
* :ghpull:`19298`: Fix misplaced colon in bug report template.
* :ghpull:`19297`: Clarify return format of Line2D.get_data.
* :ghpull:`19277`: Warn on redundant definition of plot properties
* :ghpull:`19278`: Cleanup and document _plot_args()
* :ghpull:`19282`: Remove the unused TransformNode._gid.
* :ghpull:`19264`: Expand on slider_demo example
* :ghpull:`19244`: Move cbook._check_isinstance() to _api.check_isinstance()
* :ghpull:`19273`: Use proper pytest functionality for warnings and exceptions
* :ghpull:`19262`: more robust check for enter key in TextBox
* :ghpull:`19249`: Clarify Doc for Secondary axis, ad-hoc example
* :ghpull:`19248`: Make return value of _get_patch_verts always an array.
* :ghpull:`19247`: Fix markup for mplot3d example.
* :ghpull:`19216`: Ignore non-draw codes when calculating path extent
* :ghpull:`19215`: Collect information for setting up a development environment
* :ghpull:`19210`: Fix creation of AGG images bigger than 1024**3 pixels
* :ghpull:`18933`: Set clip path for PostScript texts.
* :ghpull:`19162`: Deprecate cbook.warn_deprecated and move internal calls to _api.warn_deprecated
* :ghpull:`16391`: Re-write sym-log-norm
* :ghpull:`19240`: FIX: process lists for inverse norms
* :ghpull:`18737`: Fix data cursor for images with additional transform
* :ghpull:`18642`: Propagate minpos from Collections to Axes.datalim
* :ghpull:`19242`: Update first occurrence of QT to show both 4 and 5
* :ghpull:`19231`: Add reference section to all statistics examples
* :ghpull:`19217`: Request an autoscale at the end of ax.pie()
* :ghpull:`19176`: Deprecate additional positional args to plot_{surface,wireframe}.
* :ghpull:`19063`: Give plot_directive output a ``max-width: 100%``
* :ghpull:`19187`: Support callable for formatting of Sankey labels
* :ghpull:`19220`: Remove one TOC level from the release guide
* :ghpull:`19212`: MNT: try to put more whitespace in welcome message
* :ghpull:`19155`: Consolidated the Install from Source docs
* :ghpull:`19208`: added version ask/hint to issue templates, grammar on pr bot
* :ghpull:`19185`: Document Triangulation.triangles
* :ghpull:`19181`: Remove unused imports
* :ghpull:`19207`: Fix Grouper example code
* :ghpull:`19204`: Clarify Date Format Example
* :ghpull:`19200`: Fix incorrect statement regarding test images cache size.
* :ghpull:`19198`: Fix link in contributing docs
* :ghpull:`19196`: Fix PR welcome action
* :ghpull:`19188`: Cleanup comparison between X11/CSS4 and xkcd colors
* :ghpull:`19194`: Fix trivial quiver doc typo.
* :ghpull:`19180`: Fix Artist.remove_callback()
* :ghpull:`19192`: Fixed part of Issue - #19100, changed documentation for axisartist
* :ghpull:`19179`: Check that no new figures are created in image comparison tests
* :ghpull:`19184`: Minor doc cleanup
* :ghpull:`19093`: DOCS: Specifying Colors tutorial format & arrange
* :ghpull:`17107`: Add Spines class as a container for all Axes spines
* :ghpull:`18829`: Create a RangeSlider widget
* :ghpull:`18873`: Getting Started GSoD
* :ghpull:`19175`: Fix axes direction for a floating axisartist
* :ghpull:`19130`: DOC: remove reference to 2.2.x branches from list of active branches
* :ghpull:`15212`: Dedupe window-title setting by moving it to FigureManagerBase.
* :ghpull:`19172`: Fix 3D surface example bug for non-square grid
* :ghpull:`19173`: Ensure backend tests are skipped if unavailable
* :ghpull:`19170`: Clarify meaning of facecolors for LineCollection
* :ghpull:`18310`: Add 3D stem plot
* :ghpull:`18127`: Implement lazy autoscaling in mplot3d.
* :ghpull:`16178`: Add multiple label support for Axes.plot()
* :ghpull:`19151`: Deprecate @cbook.deprecated and move internal calls to @_api.deprecated
* :ghpull:`19088`: Ignore CLOSEPOLY vertices when computing dataLim from patches
* :ghpull:`19166`: CI: add github action to post to first-time PRs openers
* :ghpull:`19124`: GOV/DOC: add section to docs on triaging and triage team
* :ghpull:`15602`: Add an auto-labeling helper function for bar charts
* :ghpull:`19164`: docs: fix simple typo, backslahes -> backslashes
* :ghpull:`19161`: Simplify test_backend_pdf::test_multipage_properfinalize.
* :ghpull:`19141`: FIX: suppress offset text in ConciseDateFormatter when largest scale is in years
* :ghpull:`19150`: Move from @cbook._classproperty to @_api.classproperty
* :ghpull:`19144`: Move from cbook._warn_external() to _api.warn_external()
* :ghpull:`19119`: Don't lose unit change handlers when pickling/unpickling.
* :ghpull:`19145`: Move from cbook._deprecate_*() to _api.deprecate_*()
* :ghpull:`19123`: Use Qt events to refresh pixel ratio.
* :ghpull:`19056`: Support raw/rgba frame format in FFMpegFileWriter
* :ghpull:`19140`: Fix the docstring of suptitle/subxlabel/supylabel.
* :ghpull:`19132`: Normalize docstring interpolation label for kwdoc() property lists
* :ghpull:`19134`: Switch internal API function calls from cbook to _api
* :ghpull:`19138`: Added non-code contributions to incubator docs
* :ghpull:`19125`: DOC: contributor incubator
* :ghpull:`18948`: DOC: Fix latexpdf build
* :ghpull:`18753`: Remove several more deprecations
* :ghpull:`19083`: Fix headless tests on Wayland.
* :ghpull:`19127`: Cleanups to webagg & friends.
* :ghpull:`19122`: FIX/DOC - make Text doscstring interp more easily searchable
* :ghpull:`19106`: Support setting rcParams["image.cmap"] to Colormap instances.
* :ghpull:`19085`: FIX: update a transform from transFigure to transSubfigure
* :ghpull:`19117`: Rename a confusing variable.
* :ghpull:`18647`: Axes.axline: implement support transform argument (for points but not slope)
* :ghpull:`16220`: Fix interaction with unpickled 3d plots.
* :ghpull:`19059`: Support blitting in webagg backend
* :ghpull:`19107`: Update pyplot.py
* :ghpull:`19044`: Cleanup Animation frame_formats.
* :ghpull:`19087`: FIX/TST: recursively remove ticks
* :ghpull:`19094`: Suppress -Wunused-function about _import_array when compiling tkagg.cpp.
* :ghpull:`19092`: Fix use transform mplot3d
* :ghpull:`19097`: DOC: add FuncScale to set_x/yscale
* :ghpull:`19089`: ENH: allow passing a scale instance to set_scale
* :ghpull:`19086`: FIX: add a default scale to Normalize
* :ghpull:`19073`: Mention in a few more places that artists default to not-pickable.
* :ghpull:`19079`: Remove incorrect statement about ``hist(..., log=True)``.
* :ghpull:`19076`: Small improvements to aitoff projection.
* :ghpull:`19071`: DOC: Add 'blackman' to list of imshow interpolations
* :ghpull:`17524`: ENH: add supxlabel and supylabel
* :ghpull:`18840`: Add tutorial about autoscaling
* :ghpull:`19042`: Simplify GridHelper invalidation.
* :ghpull:`19048`: Remove _draw_{ticks2,label2}; skip extents computation in _update_ticks.
* :ghpull:`18983`: Pass norm argument to spy
* :ghpull:`18802`: Add code of conduct
* :ghpull:`19060`: Fix broken link in Readme
* :ghpull:`18569`: More generic value snapping for Slider widgets
* :ghpull:`19055`: Fix kwargs handling in AnnotationBbox
* :ghpull:`19041`: Reword docs for exception_handler in CallbackRegistry.
* :ghpull:`19046`: Prepare inlining MovieWriter.cleanup() into MovieWriter.finish().
* :ghpull:`19050`: Better validate tick direction.
* :ghpull:`19038`: Fix markup in interactive figures doc.
* :ghpull:`19035`: grid_helper_curvelinear cleanups.
* :ghpull:`19022`: Update event handling docs.
* :ghpull:`19025`: Remove individual doc entries for some methods Axes inherits from Artist
* :ghpull:`19018`: Inline and optimize ContourLabeler.get_label_coords.
* :ghpull:`19019`: Deprecate never used ``resize_callback`` param to FigureCanvasTk.
* :ghpull:`19023`: Cleanup comments/docs in backend_macosx, backend_pdf.
* :ghpull:`19020`: Replace mathtext assertions by unpacking.
* :ghpull:`19024`: Dedupe docs of GridSpec.subplots.
* :ghpull:`19013`: Improve docs of _get_packed_offsets, _get_aligned_offsets.
* :ghpull:`19009`: Compactify the implementation of ContourLabeler.add_label_near.
* :ghpull:`19008`: Deprecate event processing wrapper methods on FigureManagerBase.
* :ghpull:`19015`: Better document multilinebaseline (and other small TextArea fixes)
* :ghpull:`19012`: Common ``__init__`` for VPacker and HPacker.
* :ghpull:`19014`: Support normalize_kwargs(None) (== {}).
* :ghpull:`19010`: Inline _print_pdf_to_fh, _print_png_to_fh.
* :ghpull:`19003`: Remove reference to unicode-math in pgf preamble.
* :ghpull:`18847`: Cleanup interactive pan/zoom.
* :ghpull:`18868`: Expire _make_keyword_only deprecations from 3.2
* :ghpull:`18903`: Move cbook._suppress_matplotlib_deprecation_warning() from cbook to _api
* :ghpull:`18997`: Micro-optimize check_isinstance.
* :ghpull:`18995`: Fix the doc of GraphicsContextBase.set_clip_rectangle.
* :ghpull:`18996`: Fix API change message from #18989
* :ghpull:`18993`: Don't access private renderer attributes in tkagg blit.
* :ghpull:`18980`: DOC: fix typos
* :ghpull:`18989`: The Artist property rasterized cannot be None anymore
* :ghpull:`18987`: Fix punctuation in doc.
* :ghpull:`18894`: Use selectfont instead of findfont + scalefont + setfont in PostScript.
* :ghpull:`18990`: Minor cleanup of categorical example
* :ghpull:`18947`: Strictly increasing check with test coverage for streamplot grid
* :ghpull:`18981`: Cleanup Firefox SVG example.
* :ghpull:`18969`: Improve documentation on rasterization
* :ghpull:`18876`: Support fully-fractional HiDPI added in Qt 5.14.
* :ghpull:`18976`: Simplify contour_label_demo.
* :ghpull:`18975`: Fix typing error in pyplot's docs
* :ghpull:`18956`: Document rasterized parameter in pcolormesh() explicitly
* :ghpull:`18968`: Fix clabel() for backends without canvas.get_renderer()
* :ghpull:`18949`: Deprecate AxisArtist.ZORDER
* :ghpull:`18830`: Pgf plotting
* :ghpull:`18967`: Remove unnecessary calls to lower().
* :ghpull:`18910`: Remove Artist.eventson and Container.eventson
* :ghpull:`18964`: Remove special-casing for PostScript dpi in pyplot.py.
* :ghpull:`18961`: Replace sphinx-gallery-specific references by standard :doc: refs.
* :ghpull:`18955`: added needs_ghostscript; skip test
* :ghpull:`18857`: Improve hat graph example
* :ghpull:`18943`: Small cleanup to StepPatch._update_path.
* :ghpull:`18937`: Cleanup stem docs and simplify implementation.
* :ghpull:`18895`: Introduce variable since which mpl version the minimal python version
* :ghpull:`18927`: Improve warning message for missing font family specified via alias.
* :ghpull:`18930`: Document limitations of Path.contains_point() and clarify its semantics
* :ghpull:`18892`: Fixes MIME type for svg frame_format in HTMLWriter.
* :ghpull:`18938`: Edit usetex docs.
* :ghpull:`18923`: Use lambdas to prevent gc'ing and deduplication of widget callbacks.
* :ghpull:`16171`: Contour fixes/improvements
* :ghpull:`18901`: Simplify repeat_delay and fix support for it when using iterable frames.
* :ghpull:`18911`: Added Aria-Labels to all inputs with tooltips for generated HTML animations: issue #17910
* :ghpull:`18912`: Use CallbackRegistry for {Artist,Collection}.add_callback.
* :ghpull:`18919`: DOCS: fix contourf hatch demo legend
* :ghpull:`18905`: Make docs fail on Warning (and fix all existing warnings)
* :ghpull:`18763`: Single-line string notation for subplot_mosaic
* :ghpull:`18902`: Move ImageMagick version exclusion to _get_executable_info.
* :ghpull:`18915`: Remove hard-coded API removal version mapping.
* :ghpull:`18914`: Fix typo in error message: interable -> iterable.
* :ghpull:`15065`: step-between as drawstyle [Alternative approach to #15019]
* :ghpull:`18532`: Consistent behavior of draw_if_interactive across interactive backends.
* :ghpull:`18908`: Rework interactive backends tests.
* :ghpull:`18817`: MAINT: deprecate validCap, validJoin
* :ghpull:`18907`: Unmark wx-threading-test-failure as strict xfail.
* :ghpull:`18896`: Add note on keeping a reference to animation docstrings
* :ghpull:`18862`: Resolve mathtext.fontset at FontProperties creation time.
* :ghpull:`18877`: Remove fallback to nonexistent setDevicePixelRatioF.
* :ghpull:`18823`: Move from @cbook.deprecated to @_api.deprecated
* :ghpull:`18889`: Switch Tk to using PNG files for buttons
* :ghpull:`18888`: Update version of Matplotlib that needs Python 3.7
* :ghpull:`18867`: Remove "Demo" from example titles (part 2)
* :ghpull:`18863`: Reword FontProperties docstring.
* :ghpull:`18866`: Fix RGBAxes docs markup.
* :ghpull:`18874`: Slightly compress down the pgf tests.
* :ghpull:`18565`: Make Tkagg blit thread safe
* :ghpull:`18858`: Remove "Demo" from example titles
* :ghpull:`15177`: Bind WX_CHAR_HOOK instead of WX_KEY_DOWN for wx key_press_event.
* :ghpull:`18821`: Simplification of animated histogram example
* :ghpull:`18844`: Fix sphinx formatting issues
* :ghpull:`18834`: Add cross-references to Artist tutorial
* :ghpull:`18827`: Update Qt version in event handling docs.
* :ghpull:`18825`: Warn in pgf backend when unknown font is requested.
* :ghpull:`18822`: Remove deprecate
* :ghpull:`18733`: Time series histogram plot example
* :ghpull:`18812`: Change LogFormatter coeff computation
* :ghpull:`18820`: Fix axes -> Axes changes in figure.py
* :ghpull:`18657`: Move cbook.deprecation to _api.deprecation
* :ghpull:`18818`: Clarify behavior of CallbackRegistry.disconnect with nonexistent cids.
* :ghpull:`18811`: DOC Use 'Axes' instead of 'axes' in figure.py
* :ghpull:`18814`: [Example] update Anscombe's Quartet
* :ghpull:`18806`: DOC Use 'Axes' in _axes.py docstrings
* :ghpull:`18799`: Remove unused wx private attribute.
* :ghpull:`18772`: BF: text not drawn shouldn't count for tightbbox
* :ghpull:`18793`: Consistently use axs to refer to a set of Axes (v2)
* :ghpull:`18792`: Cmap cleanup
* :ghpull:`18798`: Deprecate ps.useafm for mathtext
* :ghpull:`18302`: Remove 3D attributes from renderer
* :ghpull:`18795`: Make inset indicator more visible in the example
* :ghpull:`18781`: Update description of web application server example.
* :ghpull:`18791`: Fix documentation of edgecolors precedence for scatter()
* :ghpull:`14645`: Add a helper to copy a colormap and set its extreme colors.
* :ghpull:`17709`: Enh: SymNorm for normalizing symmetrical data around a center
* :ghpull:`18780`: CI: pydocstyle>=5.1.0, flake8-docstrings>=1.4.0 verified to work
* :ghpull:`18200`: Unpin pydocstyle
* :ghpull:`18767`: Turn "How to use Matplotlib in a web application server" into a sphinx-gallery example
* :ghpull:`18765`: Remove some unused tick private attributes.
* :ghpull:`18688`: Shorter property deprecation.
* :ghpull:`18748`: Allow dependabot to check GitHub actions daily
* :ghpull:`18529`: Synchronize view limits of shared axes after setting ticks
* :ghpull:`18575`: Colorbar grid position
* :ghpull:`18744`: DOCS: document log locator's ``numticks``
* :ghpull:`18687`: Deprecate GraphicsContextPS.
* :ghpull:`18706`: Consistently use 3D, 2D, 1D for dimensionality
* :ghpull:`18702`: _make_norm_from_scale fixes.
* :ghpull:`18558`: Support usetex in date Formatters
* :ghpull:`18493`: MEP22 toolmanager set axes navigate_mode
* :ghpull:`18730`: TST: skip if known-bad version of imagemagick
* :ghpull:`18583`: Support binary comms in nbagg.
* :ghpull:`18728`: Disable mouseover info for NonUniformImage.
* :ghpull:`18710`: Deprecate cla() methods of Axis and Spines in favor of clear()
* :ghpull:`18719`: Added the trace plot of the end point
* :ghpull:`18729`: Use ax.add_image rather than ax.images.append in NonUniformImage example
* :ghpull:`18707`: Use "Return whether ..." docstring for functions returning bool
* :ghpull:`18724`: Remove extra newlines in contour(f) docs.
* :ghpull:`18696`: removed glossary
* :ghpull:`18721`: Remove the use_cmex font fallback mechanism.
* :ghpull:`18680`: wx backend API cleanups.
* :ghpull:`18709`: Use attributes Axes.x/yaxis instead of Axes.get_x/yaxis()
* :ghpull:`18712`: Shorten GraphicsContextWx.get_wxcolour.
* :ghpull:`18708`: Individualize contour and contourf docstrings
* :ghpull:`18663`: fix: keep baseline scale to baseline 0 even if set to None
* :ghpull:`18704`: Fix docstring of Axes.cla()
* :ghpull:`18675`: Merge ParasiteAxesAuxTransBase into ParasiteAxesBase.
* :ghpull:`18651`: Allow Type3 subsetting of otf fonts in pdf backend.
* :ghpull:`17396`: Improve headlessness detection for backend selection.
* :ghpull:`17737`: Deprecate BoxStyle._Base.
* :ghpull:`18655`: Sync SubplotDivider API with SubplotBase API changes.
* :ghpull:`18582`: Shorten mlab tests.
* :ghpull:`18599`: Simplify wx rubberband drawing.
* :ghpull:`18671`: DOC: fix autoscale docstring
* :ghpull:`18637`: BLD: sync build and run time numpy pinning
* :ghpull:`18693`: Also fix tk key mapping, following the same strategy as for gtk.
* :ghpull:`18691`: Cleanup sample_data.
* :ghpull:`18697`: Catch TypeError when validating rcParams types.
* :ghpull:`18537`: Create security policy
* :ghpull:`18356`: ENH: Subfigures
* :ghpull:`18694`: Document limitations on ``@deprecated`` with multiple-inheritance.
* :ghpull:`18669`: Rework checks for old macosx
* :ghpull:`17791`: More accurate handling of unicode/numpad input in gtk3 backends.
* :ghpull:`18679`: Further simplify pgf tmpdir cleanup.
* :ghpull:`18685`: Cleanup pgf examples
* :ghpull:`18682`: Small API cleanups to plot_directive.
* :ghpull:`18686`: Numpydocify setp.
* :ghpull:`18684`: Small simplification to triage_tests.py.
* :ghpull:`17832`: pdf: Support setting URLs on Text objects
* :ghpull:`18674`: Remove accidentally added swapfile.
* :ghpull:`18673`: Small cleanups to parasite axes.
* :ghpull:`18536`: axes3d panning
* :ghpull:`18667`: TST: Lock cache directory during cleanup.
* :ghpull:`18672`: Created Border for color examples
* :ghpull:`18661`: Define GridFinder.{,inv\_}transform_xy as normal methods.
* :ghpull:`18656`: Fix some missing references.
* :ghpull:`18659`: Small simplifications to BboxImage.
* :ghpull:`18511`: feat: StepPatch to take array as baseline
* :ghpull:`18646`: Support activating figures with plt.figure(figure_instance).
* :ghpull:`18370`: Move PostScript Type3 subsetting to pure python.
* :ghpull:`18645`: Simplify Colorbar.set_label, inline Colorbar._edges.
* :ghpull:`18633`: Support linestyle='none' in Patch
* :ghpull:`18527`: Fold ColorbarPatch into Colorbar, deprecate colorbar_factory.
* :ghpull:`17480`: Regenerate background when RectangleSelector active-flag is set back on.
* :ghpull:`18626`: Specify case when parameter is ignored.
* :ghpull:`18634`: Fix typo in warning message.
* :ghpull:`18603`: bugfix #18600 by using the MarkerStyle copy constructor
* :ghpull:`18628`: Remove outdate comment about canvases with no manager attribute.
* :ghpull:`18591`: Deprecate MathTextParser("bitmap") and associated APIs.
* :ghpull:`18617`: Remove special styling of sidebar heading
* :ghpull:`18616`: Improve instructions for building the docs
* :ghpull:`18623`: Provide a 'cursive' font present in Windows' default font set.
* :ghpull:`18579`: Fix stairs() tests
* :ghpull:`18618`: Correctly separate two fantasy font names.
* :ghpull:`18610`: DOCS: optional doc building dependencies
* :ghpull:`18601`: Simplify Rectangle and RegularPolygon.
* :ghpull:`18573`: add_subplot(..., axes_class=...) for more idiomatic mpl_toolkits usage.
* :ghpull:`18605`: Correctly sync state of wx toolbar buttons when triggered by keyboard.
* :ghpull:`18606`: Revert "FIX: pin pytest"
* :ghpull:`18587`: Fix docstring of zaxis_date.
* :ghpull:`18589`: Factor out pdf Type3 glyph drawing.
* :ghpull:`18586`: Text cleanups.
* :ghpull:`18594`: FIX: pin pytest
* :ghpull:`18577`: Random test cleanups
* :ghpull:`18578`: Merge all axisartist axis_direction demos together.
* :ghpull:`18588`: Use get_x/yaxis_transform more.
* :ghpull:`18585`: FIx precision in pie and donut example
* :ghpull:`18564`: Prepare for merging SubplotBase into AxesBase.
* :ghpull:`15127`: ENH/API: improvements to register_cmap
* :ghpull:`18576`: DOC: prefer colormap over color map
* :ghpull:`18340`: Colorbar grid position
* :ghpull:`18568`: Added Reporting to code_of_conduct.md
* :ghpull:`18555`: Convert _math_style_dict into an Enum.
* :ghpull:`18567`: Replace subplot(ijk) calls by subplots(i, j)
* :ghpull:`18554`: Replace some usages of plt.subplot() by plt.subplots() in tests
* :ghpull:`18556`: Accept same types to errorevery as markevery
* :ghpull:`15932`: Use test cache for test result images too.
* :ghpull:`18557`: DOC: Add an option to disable Google Analytics.
* :ghpull:`18560`: Remove incorrect override of pcolor/contour in parasite axes.
* :ghpull:`18566`: Use fig, ax = plt.subplots() in tests (part 2)
* :ghpull:`18553`: Use fig, ax = plt.subplots() in tests
* :ghpull:`11748`: get_clip_path checks for nan
* :ghpull:`8987`: Tick formatter does not support grouping with locale
* :ghpull:`18552`: Change \*subplot(111, ...) to \*subplot(...) as 111 is the default.
* :ghpull:`18189`: FIX: Add get/set methods for 3D collections
* :ghpull:`18430`: FIX: do not reset ylabel ha when changing position
* :ghpull:`18515`: Remove deprecated backend code.
* :ghpull:`17935`: MNT: improve error messages on bad pdf metadata input
* :ghpull:`18525`: Add Text3D position getter/setter
* :ghpull:`18542`: CLEANUP: validate join/cap style centrally
* :ghpull:`18501`: TST: Add test for _repr_html_
* :ghpull:`18528`: Deprecate TextArea minimumdescent.
* :ghpull:`18543`: Documentation improvements for stairs()
* :ghpull:`18531`: Unit handling improvements
* :ghpull:`18523`: Don't leak file paths into PostScript metadata
* :ghpull:`18526`: Templatize _image.resample to deduplicate it.
* :ghpull:`18522`: Remove mlab, toolkits, and misc deprecations
* :ghpull:`18516`: Remove deprecated font-related things.
* :ghpull:`18535`: Add a code of conduct link to github
* :ghpull:`17521`: Remove font warning when legend is added while using Tex
* :ghpull:`18517`: Include kerning when outputting pdf strings.
* :ghpull:`18521`: Inline some helpers in ColorbarBase.
* :ghpull:`18512`: Private api2
* :ghpull:`18519`: Correctly position text with nonzero descent with afm fonts / ps output.
* :ghpull:`18513`: Remove Locator.autoscale.
* :ghpull:`18497`: Merge v3.3.x into master
* :ghpull:`18502`: Remove the deprecated matplotlib.cm.revcmap()
* :ghpull:`18506`: Inline ScalarFormatter._formatSciNotation.
* :ghpull:`18455`: Fix BoundingBox in EPS files.
* :ghpull:`18275`: feat: StepPatch
* :ghpull:`18507`: Fewer "soft" dependencies on LaTeX packages.
* :ghpull:`18378`: Deprecate public access to many mathtext internals.
* :ghpull:`18494`: Move cbook._check_in_list() to _api.check_in_list()
* :ghpull:`18423`: 2-D array RGB and RGBA values not understood in plt.plot()
* :ghpull:`18492`: Fix doc build failure due to #18440
* :ghpull:`18435`: New environment terminal language
* :ghpull:`18456`: Reuse InsetLocator to make twinned axes follow their parents.
* :ghpull:`18440`: List existing rcParams in rcParams docstring.
* :ghpull:`18453`: FIX: allow manually placed axes in constrained_layout
* :ghpull:`18473`: Correct link to widgets examples
* :ghpull:`18466`: Remove unnecessary autoscale handling in hist().
* :ghpull:`18465`: Don't modify bottom argument in place in stacked histograms.
* :ghpull:`18468`: Cleanup multiple_yaxis_with_spines example.
* :ghpull:`18463`: Improve formatting of defaults in docstrings.
* :ghpull:`6268`: ENH: support alpha arrays in collections
* :ghpull:`18449`: Remove the private Axes._set_position.
* :ghpull:`18460`: DOC: example gray level in 'Specifying Colors' tutorial
* :ghpull:`18426`: plot directive: caption-option
* :ghpull:`18444`: Support double-click in webagg/nbagg
* :ghpull:`12518`: Example showing scale-invariant angle arc
* :ghpull:`18446`: Normalize properties passed to ToolHandles.
* :ghpull:`18445`: Warn if an animation is gc'd before doing anything.
* :ghpull:`18452`: Move Axes ``__repr__`` from Subplot to AxesBase.
* :ghpull:`15374`: Replace _prod_vectorized by @-multiplication.
* :ghpull:`13643`: RecangleSelector constructor does not handle marker_props
* :ghpull:`18403`: DOC: Remove related topics entries from the sidebar
* :ghpull:`18421`: Move {get,set}_{x,y}label to _AxesBase.
* :ghpull:`18429`: DOC: fix date example
* :ghpull:`18353`: DOCS: describe shared axes behavior with units
* :ghpull:`18420`: Always strip out date in postscript's test_savefig_to_stringio.
* :ghpull:`18422`: Decrease output when running ``pytest -s``.
* :ghpull:`18418`: Cleanup menu example
* :ghpull:`18419`: Avoid demo'ing passing kwargs to gca().
* :ghpull:`18372`: DOC: Fix various missing references and typos
* :ghpull:`18400`: Clarify argument name in constrained_layout error message
* :ghpull:`18384`: Clarification in ArtistAnimation docstring
* :ghpull:`17892`: Add earlier color validation
* :ghpull:`18367`: Support horizontalalignment in TextArea/AnchoredText.
* :ghpull:`18362`: DOC: Add some types to Returns entries.
* :ghpull:`18365`: move canvas focus after toomanager initialization
* :ghpull:`18360`: Add example for specifying figure size in different units
* :ghpull:`18341`: DOCS: add action items to PR template
* :ghpull:`18349`: Remove redundant angles in ellipse demo.
* :ghpull:`18145`: Created a parameter fontset that can be used in each Text element
* :ghpull:`18344`: More nouns/imperative forms in docs.
* :ghpull:`18308`: Synchronize units change in Axis.set_units for shared axis
* :ghpull:`17494`: Rewrite of constrained_layout....
* :ghpull:`16646`: update colorbar.py make_axes_gridspec
* :ghpull:`18306`: Fix configure subplots
* :ghpull:`17509`: Fix ``swap_if_landscape`` call in backend_ps
* :ghpull:`18323`: Deleted "Our Favorite Recipes" section and moved the examples.
* :ghpull:`18128`: Change several deprecated symbols in _macosx.m
* :ghpull:`18251`: Merge v3.3.x into master
* :ghpull:`18329`: Change default keymap in toolmanager example.
* :ghpull:`18330`: Dedent rst list.
* :ghpull:`18286`: Fix imshow to work with subclasses of ndarray.
* :ghpull:`18320`: Make Colorbar outline into a Spine.
* :ghpull:`18316`: Safely import pyplot if a GUI framework is already running.
* :ghpull:`18321`: Capture output of CallbackRegistry exception test.
* :ghpull:`17900`: Add getters and _repr_html_ for over/under/bad values of Colormap objects.
* :ghpull:`17930`: Fix errorbar property cycling to match plot.
* :ghpull:`18290`: Remove unused import to fix flake8.
* :ghpull:`16818`: Dedupe implementations of configure_subplots().
* :ghpull:`18284`: TkTimer interval=0 workaround
* :ghpull:`17901`: DOC: Autoreformating of backend/\*.py
* :ghpull:`17291`: Normalize gridspec ratios to lists in the setter.
* :ghpull:`18226`: Use CallbackRegistry in Widgets and some related cleanup
* :ghpull:`18203`: Force locator and formatter inheritance
* :ghpull:`18279`: boxplot: Add conf_intervals reference to notch docs.
* :ghpull:`18276`: Fix autoscaling to exclude infinite data limits when possible.
* :ghpull:`18261`: Migrate tk backend tests into subprocesses
* :ghpull:`17961`: DOCS: Remove How-to: Contributing
* :ghpull:`18201`: Remove mpl.colors deprecations for 3.4
* :ghpull:`18223`: Added example on how to make packed bubble charts
* :ghpull:`18264`: Fix broken links in doc build.
* :ghpull:`8031`: Add errorbars to mplot3d
* :ghpull:`18187`: Add option to create horizontally-oriented stem plots
* :ghpull:`18250`: correctly autolabel Documentation and Maintenance issues
* :ghpull:`18161`: Add more specific GitHub issue templates
* :ghpull:`18181`: Replace ttconv by plain python for pdf subsetting
* :ghpull:`17371`: add context manager functionality to ion and ioff
* :ghpull:`17789`: Tk backend improvements
* :ghpull:`15532`: Resolve 'text ignores rotational part of transformation' (#698)
* :ghpull:`17851`: Fix Axes3D.add_collection3d issues
* :ghpull:`18205`: Hat graph example
* :ghpull:`6168`: #5856: added option to create vertically-oriented stem plots
* :ghpull:`18202`: Remove mpl.testing deprecations for 3.4
* :ghpull:`18081`: Support scale in ttf composite glyphs
* :ghpull:`18199`: Some cleanup on TickedStroke
* :ghpull:`18190`: Use ``super()`` more in  backends
* :ghpull:`18193`: Allow savefig to save SVGs on FIPS enabled systems #18192
* :ghpull:`17802`: fix FigureManagerTk close behavior if embedded in Tk App
* :ghpull:`15458`: TickedStroke, a stroke style with ticks useful for depicting constraints
* :ghpull:`18178`: DOC: clarify that display space coordinates are not stable
* :ghpull:`18172`: allow webAgg to report middle click events
* :ghpull:`17578`: Search for minus of any font size to get height of tex result
* :ghpull:`17546`: ``func`` argument in ``legend_elements`` with non-monotonically increasing functions
* :ghpull:`17684`: Deprecate passing bytes to FT2Font.set_text.
* :ghpull:`17500`: Tst improve memleak
* :ghpull:`17669`: Small changes to svg font embedding details
* :ghpull:`18095`: Error on unexpected kwargs in scale classes
* :ghpull:`18106`: Copy docstring description from Axes.legend() to Figure.legend()
* :ghpull:`18002`: Deprecate various vector-backend-specific mathtext helpers.
* :ghpull:`18006`: Fix ToolManager inconsistencies with regular toolbar
* :ghpull:`18004`: Typos and docs for mathtext fonts.
* :ghpull:`18133`: DOC: Update paths for moved API/what's new fragments
* :ghpull:`18122`: Document and test legend argument parsing
* :ghpull:`18124`: Fix FuncAnimation._draw_frame exception and testing
* :ghpull:`18125`: pdf: Convert operator list to an Enum.
* :ghpull:`18123`: Cleanup figure title example
* :ghpull:`18121`: Improve rasterization demo
* :ghpull:`18012`: Add explanatory text for rasterization demo
* :ghpull:`18103`: Support data reference for hexbin() parameter C
* :ghpull:`17826`: Add pause() and resume() methods to the base Animation class
* :ghpull:`18090`: Privatize cbook.format_approx.
* :ghpull:`18080`: Reduce numerical precision in Type 1 fonts
* :ghpull:`18044`: Super-ify parts of the code base, part 3
* :ghpull:`18087`: Add a note on working around limit expansion of set_ticks()
* :ghpull:`18071`: Remove deprecated animation code
* :ghpull:`17822`: Check for float values for min/max values to ax{v,h}line
* :ghpull:`18069`: Remove support for multiple-color strings in to_rgba_array
* :ghpull:`18070`: Remove rcsetup deprecations
* :ghpull:`18073`: Remove disable_internet.py
* :ghpull:`18075`: typo in usetex.py example
* :ghpull:`18043`:  Super-ify parts of the code base, part 2
* :ghpull:`18062`: Bump matplotlib.patches coverage
* :ghpull:`17269`: Fix ConciseDateFormatter when plotting a range included in a second
* :ghpull:`18063`: Remove un-used trivial setters and getters
* :ghpull:`18025`: add figpager as a third party package
* :ghpull:`18046`: Discourage references in section headings.
* :ghpull:`18042`: scatter: Raise if unexpected type of ``s`` argument.
* :ghpull:`18028`: Super-ify parts of the code base, part 1
* :ghpull:`18029`: Remove some unused imports.
* :ghpull:`18018`: Cache realpath resolution in font_manager.
* :ghpull:`18013`: Use argumentless ``super()`` more.
* :ghpull:`17988`: add test with -OO
* :ghpull:`17993`: Make inset_axes and secondary_axis picklable.
* :ghpull:`17992`: Shorten tight_bbox.
* :ghpull:`18003`: Deprecate the unneeded Fonts.destroy.
* :ghpull:`16457`: Build lognorm/symlognorm from corresponding scales.
* :ghpull:`17966`: Fix some words
* :ghpull:`17803`: Simplify projection-of-point-on-polyline in contour.py.
* :ghpull:`17699`: raise RuntimeError appropriately for animation update func
* :ghpull:`17954`: Remove another overspecified latex geometry.
* :ghpull:`17948`: Sync Cairo's usetex measurement with base class.
* :ghpull:`17788`: Tighten a bit the RendererAgg API.
* :ghpull:`12443`: Warn in colorbar() when mappable.axes != figure.gca().
* :ghpull:`17926`: Deprecate hatch patterns with invalid values
* :ghpull:`17922`: Rewrite the barcode example
* :ghpull:`17890`: Properly use thin space after math text operator
* :ghpull:`16090`: Change pcolormesh snapping (fixes alpha colorbar/grid issues) [AGG]
* :ghpull:`17842`: Move "Request a new feature" from How-to to Contributing
* :ghpull:`17897`: Force origin='upper' in pyplot.specgram
* :ghpull:`17929`: Improve hatch demo
* :ghpull:`17927`: Remove unnecessary file save during test
* :ghpull:`14896`: Updated doc in images.py by adding direct link to 24-bit stink bug png
* :ghpull:`17909`: frame_format to support all listed by animation writers
* :ghpull:`13569`: Style cleanup to pyplot.
* :ghpull:`17924`: Remove the example "Easily creating subplots"
* :ghpull:`17869`: FIX: new date rcParams weren't being evaluated
* :ghpull:`17921`: Added density and combination hatching examples
* :ghpull:`17159`: Merge consecutive rasterizations
* :ghpull:`17895`: Use indexed color for PNG images in PDF files when possible
* :ghpull:`17894`: DOC: Numpydoc format.
* :ghpull:`17884`: Created Hatch marker styles Demo for Example Gallery
* :ghpull:`17347`: ENH: reuse oldgridspec is possible...
* :ghpull:`17915`: Document that set_ticks() increases view limits if necessary
* :ghpull:`17902`: Fix figure size in path effects guide
* :ghpull:`17899`: Add missing space in cairo error
* :ghpull:`17888`: Add _repr_png_ and _repr_html_ to Colormap objects.
* :ghpull:`17830`: Fix BoundaryNorm for multiple colors and one region
* :ghpull:`17883`: Remove Python 3.6 compatibility shims
* :ghpull:`17889`: Minor doc fixes
* :ghpull:`17879`: Link to style-file example page in style tutorial
* :ghpull:`17876`: Fix description of subplot2grid arguments
* :ghpull:`17856`: Clarify plotnonfinite parameter docs of scatter()
* :ghpull:`17843`: Add fullscreen toggle support to WxAgg backend
* :ghpull:`17022`: ENH: add rcParam for ConciseDate and interval_multiples
* :ghpull:`17799`: Deduplicate attribute docs of ContourSet and its derived classes
* :ghpull:`17847`: Remove overspecified latex geometry.
* :ghpull:`17662`: Mnt drop py36
* :ghpull:`17845`: Fix size of donate button
* :ghpull:`17825`: Add quick-link buttons for contributing
* :ghpull:`17837`: Remove "Reporting a bug or submitting a patch" from How-to
* :ghpull:`17828`: API: treat xunits=None and yunits=None as "default"
* :ghpull:`17839`: Avoid need to lock in dvi generation, to avoid deadlocks.
* :ghpull:`17824`: Improve categorical converter error message
* :ghpull:`17834`: Keep using a single dividers LineCollection instance in colorbar.
* :ghpull:`17838`: Prefer colorbar(ScalarMappable(...)) to ColorbarBase in tutorial.
* :ghpull:`17836`: More precise axes section names in docs
* :ghpull:`17835`: Colorbar cleanups.
* :ghpull:`17727`: FIX: properly handle dates when intmult is true
* :ghpull:`15617`: Dev docs update
* :ghpull:`17819`: Fix typos in tight layout guide
* :ghpull:`17806`: Set colorbar label only in set_label.
* :ghpull:`17265`: Mnt rearrange next api again
* :ghpull:`17808`: Improve docstring of ColorbarBase.set_label()
* :ghpull:`17723`: Deprecate FigureCanvas.{get,set}_window_title.
* :ghpull:`17798`: Fix overindented bullet/enumerated lists.
* :ghpull:`17767`: Allow list of hatches to {bar, barh}
* :ghpull:`17749`: Deprecate ``FancyBboxPatch(..., boxstyle="custom", bbox_transmuter=...)``
* :ghpull:`17783`: DOC: point to bbox static "constructor" functions in set_position
* :ghpull:`17782`: MNT: update mailmap
* :ghpull:`17776`: Changes in the image for test_load_from_url
* :ghpull:`17750`: Soft-deprecate mutation_aspect=None.
* :ghpull:`17780`: Reorganize colorbar docstrings.
* :ghpull:`17778`: Fix whatsnew confusing typo.
* :ghpull:`17748`: Don't use bezier helpers in axisartist.
* :ghpull:`17700`: Remove remnants of macosx old-style toolbar.
* :ghpull:`17753`: Support location="left"/"top" for gridspec-based colorbars.
* :ghpull:`17761`: Update hard-coded results in artist tutorial
* :ghpull:`17728`: Move Win32_{Get,Set}ForegroundWindow to c_internal_utils.
* :ghpull:`17754`: Small cleanups to contour() code.
* :ghpull:`17751`: Deprecate dpi_cor property of FancyArrowPatch.
* :ghpull:`15941`: FontManager fixes.
* :ghpull:`17661`: Issue #17659: set tick color and tick labelcolor independently from rcParams
* :ghpull:`17389`: Don't duplicate docstrings of pyplot-level cmap setters.
* :ghpull:`17555`: Set Win32 AppUserModelId to fix taskbar icons.
* :ghpull:`17726`: Clarify docs of box_aspect()
* :ghpull:`17704`: Remove "created-by-matplotlib" comment in svg output.
* :ghpull:`17697`: Add description examples/pyplots/pyplot simple.py
* :ghpull:`17694`: CI: Only skip devdocs deploy if PR is to this repo.
* :ghpull:`17691`: ci: Print out reasons for not deploying docs.
* :ghpull:`17099`: Make Spines accessible by the attributes

Issues (204):

* :ghissue:`19701`: Notebook plotting regression in 3.4.0rc*
* :ghissue:`19754`: add space in python -mpip
* :ghissue:`18364`: ``Axes3d`` attaches itself to a figure, where as ``Axes`` does not
* :ghissue:`19700`: Setting pickradius regression in 3.4.0rc
* :ghissue:`19594`: code of conduct link 404s
* :ghissue:`19576`: duplicate pick events firing
* :ghissue:`19560`: segfault due to font objects when multi-threading
* :ghissue:`19598`: Axes order changed in 3.4.0rc1
* :ghissue:`19631`: subplot mosaic 1 element list
* :ghissue:`19581`: Missing kerning for single-byte strings in PDF
* :ghissue:`17769`: interactive figure close with wxpython 4.1 causes freeze / crash (segfault?)
* :ghissue:`19427`: Fix mistake in documentation
* :ghissue:`19624`: Cannot add colorbar to figure after pickle
* :ghissue:`19544`: Regression in 3.4.0rc1 in creating ListedColormap from a set
* :ghissue:`5855`: plt.step(..., where="auto")
* :ghissue:`19474`: Memory leak with CallbackRegistry
* :ghissue:`19345`: legend is eating up huge amounts of memory
* :ghissue:`19066`: plt.scatter, error with NaN values and edge color
* :ghissue:`19432`: Unexpected change in behavior in plt.subplot
* :ghissue:`18020`: Scatter3D: facecolor or color to "none" leads to an error
* :ghissue:`18939`: Warn re: Axes3D constructor behavior change in mpl3.4
* :ghissue:`19128`: webagg reports incorrect values for non-alphanumeric key events on non-qwerty keyboards
* :ghissue:`16558`: Request: for non-interactive backends make fig.canvas.draw() force the render
* :ghissue:`19234`: tick labels displaced vertically with text.usetex and xcolor
* :ghissue:`18407`: pgf backend no longer supports fig.draw
* :ghissue:`2298`: axes.xmargin/ymargin rcParam behaves differently than pyplot.margins()
* :ghissue:`19473`: Animations in Tkinter window advance non-uniformly
* :ghissue:`8688`: document moved examples
* :ghissue:`9553`: Display warning on out-of-date documentation websites
* :ghissue:`9556`: Examples page version is out of date
* :ghissue:`12374`: Examples in docs should be redirected to latest version number
* :ghissue:`19486`: Figure.tight_layout() raises MatplotlibDeprecationWarning
* :ghissue:`19445`: axline transform support broke axline in loglog scale
* :ghissue:`19178`: mathtext \lim is vertically misaligned
* :ghissue:`19446`: Better document and error handle third dimension in pyplot.text() positional argument
* :ghissue:`8790`: Inconsistent doc vs behavior for RendererXXX.draw_markers
* :ghissue:`18815`: Patch3D object does not return correct face color with get_facecolor
* :ghissue:`19152`: Automatically Aligned Labels outside Figure with Constrained Layout in Exported File
* :ghissue:`18934`: stairs() crashes with no values and one edge
* :ghissue:`11296`: Image in github repo does not match matplotlib.org (breaks image tutorial)
* :ghissue:`18699`: Issue with downloading stinkbug for "Image Tutorial"
* :ghissue:`19405`: TypeError constructor returned NULL in wayland session
* :ghissue:`18962`: Table CSS needs cleanup
* :ghissue:`19417`: CI failing on numpy...
* :ghissue:`17849`: Problems caused by changes to logic of scatter coloring in matplotlib 3.3.0.rc1
* :ghissue:`18648`: Drop support for directly imread()ing urls.
* :ghissue:`19366`: Current CI doc builds fail
* :ghissue:`19372`: matplotlib.axes.Axes.indicate_inset default label value is incompatible with LaTeX
* :ghissue:`17100`: Is it a better solution to access one of the spines by class attribute?
* :ghissue:`17375`: Proposal: add_subfigs....
* :ghissue:`19339`: constrained_layout + fixed-aspect axes + bbox_inches="tight"
* :ghissue:`19308`: Reduce whitespace in Choosing Colormaps tutorial plots
* :ghissue:`18832`: MNT: Remove AxesStack and deprecated behavior of reuse of existing axes with same arguments
* :ghissue:`19084`: Arrow coordinates slightly off when used with annotation text
* :ghissue:`17765`: PGF xelatex can't find fonts in special-character paths
* :ghissue:`19274`: Missing marker in documentation of plot
* :ghissue:`18241`: LaTeX overset: unknown symbol
* :ghissue:`19292`: Non interpolated placeholder value in docstring.
* :ghissue:`18119`: Can no longer deepcopy LogNorm objects on master
* :ghissue:`8665`: Noninteger Bases in mathtext sqrt
* :ghissue:`19243`: matplotlib doesn't build with qhull-2020.2
* :ghissue:`19275`: Double specifications of plot attributes
* :ghissue:`15066`: Feature request: stem3
* :ghissue:`19209`: Segfault when trying to create gigapixel image with agg backend
* :ghissue:`4321`: clabel ticks and axes limits with eps zoom output
* :ghissue:`16376`: ``SymLogNorm`` and ``SymLogScale`` give inconsistent results....
* :ghissue:`19239`: _make_norm_from_scale needs to process values
* :ghissue:`16552`: Scatter autoscaling still has issues with log scaling and zero values
* :ghissue:`18417`: Documentation issue template should ask for matplotlib version
* :ghissue:`19206`: matplotlib.cbook.Grouper: Example raise exception:
* :ghissue:`19203`: Date Tick Labels example
* :ghissue:`18581`: Add a check in check_figures_equal that the test did not accidentally plot on non-fixture figures
* :ghissue:`18563`: Create a RangeSlider widget
* :ghissue:`19099`: axisartist axis_direction bug
* :ghissue:`19171`: 3D surface example bug for non-square grid
* :ghissue:`18112`: set_{x,y,z}bound 3d limits are not persistent upon interactive rotation
* :ghissue:`19078`: _update_patch_limits should not use CLOSEPOLY vertices for updating
* :ghissue:`16123`: test_dpi_ratio_change fails on Windows/Qt5Agg
* :ghissue:`15796`: [DOC] PDF build of matplotlib own documentation crashes with LaTeX error "too deeply nested"
* :ghissue:`19091`: 3D Axes don't work in SubFigures
* :ghissue:`7238`: better document how to configure artists for picking
* :ghissue:`11147`: FR: add a supxlabel and supylabel as the suptitle function which are already exist
* :ghissue:`17417`: tutorial on how autoscaling works
* :ghissue:`18917`: Spy displays nothing for full arrays
* :ghissue:`18562`: Allow slider valstep to be arraylike
* :ghissue:`18942`: AnnotationBbox errors with kwargs
* :ghissue:`11472`: Mention predefined keyboard shortcuts in the docs on event-handling
* :ghissue:`18898`: wrong bounds checking in streamplot start_points
* :ghissue:`18974`: Contour label demo would benefit from some more info and/or references.
* :ghissue:`17708`: Mention rasterized option in more methods
* :ghissue:`18826`: Pgf plots with pdflatex broken
* :ghissue:`18959`: Add sphinx-gallery cross ref instructions to documenting guide
* :ghissue:`18926`: Font not installed, unclear warning
* :ghissue:`18891`: SVG animation doesn't work in HTMLWriter due to wrong type
* :ghissue:`18222`: It is painful as a new user, to figure out what AxesSubplot is
* :ghissue:`16153`: gap size for contour labels is poorly estimated
* :ghissue:`17910`: Improve accessibility of form controls in HTML widgets
* :ghissue:`18273`: Surprising behavior of shared axes with categorical units
* :ghissue:`18731`: Compact string notation for subplot_mosaic
* :ghissue:`18221`: Add example of keys to explore 3D data
* :ghissue:`18882`: Incorrect version requirement message from setup.py
* :ghissue:`18491`: Mostly unused glossary still exists in our docs
* :ghissue:`18548`: add_subplot(..., axes_cls=...)
* :ghissue:`8249`: Bug in mpl_connect(): On Windows, with the wx backend, arrow keys are not reported
* :ghissue:`15609`: [SPRINT] Update Named Colors Example
* :ghissue:`18800`: Log-scale ticker fails at 1e-323
* :ghissue:`18392`: ``scatter()``: ``edgecolor`` takes precedence over ``edgecolors``
* :ghissue:`18301`: "How to use Matplotlib in a web application server" should be made an example
* :ghissue:`18386`: Path3DCollection.set_color(self, c) does not change the color of scatter points.
* :ghissue:`8946`: Axes with sharex can have divergent axes after setting tick markers
* :ghissue:`2294`: tex option not respected by date x-axis
* :ghissue:`4382`: use new binary comm in nbagg
* :ghissue:`17088`: ``projection`` kwarg could be better documented.
* :ghissue:`18717`: Tick formatting issues on horizontal histogram with datetime on 3.3.2
* :ghissue:`12636`: Characters doesn't display correctly when figure saved as pdf with a custom font
* :ghissue:`18377`: Matplotlib picks a headless backend on Linux if Wayland is available but X11 isn't
* :ghissue:`13199`: Examples that use private APIs
* :ghissue:`18662`: Inconsistent setting of axis limits with autoscale=False
* :ghissue:`18690`: Class deprecation machinery and mixins
* :ghissue:`18510`: Build fails on OS X: wrong minimum version
* :ghissue:`18641`: Conversion cache cleaning is broken with xdist
* :ghissue:`15614`: named color examples need borders
* :ghissue:`5519`: The linestyle 'None',  ' ' and '' not supported by PathPatch.
* :ghissue:`17487`: Polygon selector with useblit=True - polygon disappears
* :ghissue:`17476`: RectangleSelector fails to clear itself after being toggled inactive and then back to active.
* :ghissue:`18600`: plt.errorbar raises error when given marker=<matplotlib.markers.MarkerStyle object>
* :ghissue:`18355`: Optional components required to build docs aren't documented
* :ghissue:`18428`: small bug in the mtplotlib gallery
* :ghissue:`4438`: inconsistent behaviour of the errorevery option in pyplot.errorbar() to the markevery keyword
* :ghissue:`5823`: please don't include the Google Analytics tracking in the off-line doc
* :ghissue:`13035`: Path3DCollection from 3D scatter cannot set_color
* :ghissue:`9725`: scatter - set_facecolors is not working on Axes3D
* :ghissue:`3370`: Patch3DCollection doesn't update color after calling set_color
* :ghissue:`18427`: yaxis.set_label_position("right") resets "horizontalalignment"
* :ghissue:`3129`: super-ify the code base
* :ghissue:`17518`: Plotting legend throws error "font family ['serif'] not found. Falling back to DejaVu Sans"
* :ghissue:`18282`: Bad interaction between kerning and non-latin1 characters in pdf output
* :ghissue:`6669`: [Feature request] Functions for "manually" plotting histograms
* :ghissue:`18411`: 2-D array RGB and RGBA values not understood in plt.plot()
* :ghissue:`18404`: Double-click events are not recognised in Jupyter notebook
* :ghissue:`12027`: marker_props is never used in the constructor of RectangleSelector
* :ghissue:`18438`: Warn when a non-started animation is gc'ed.
* :ghissue:`11259`: Symbols appear as streaks with usetex=True, times font and PDF backend
* :ghissue:`18345`: Specify what sharex and sharey do...
* :ghissue:`18082`: Feature Request: Non overlapping Bubble Plots
* :ghissue:`568`: Support error bars on 3D plots
* :ghissue:`17865`: Earlier validation of color inputs
* :ghissue:`18363`: ha="right" breaks AnchoredText placement.
* :ghissue:`11050`: keyboard shortcuts don't get registered using the experimental toolmanager with qt
* :ghissue:`17906`: Set mathtext.fontset per element
* :ghissue:`18311`: Subplot scatter plot with categorical data on y-axis with 'sharey=True' option overwrites the y-axis labels
* :ghissue:`10304`: No link to shared axes for Axis.set_units
* :ghissue:`17712`: constrained_layout fails on suptitle+colorbars+some figure sizes
* :ghissue:`14638`: colorbar.make_axes doesn't anchor in constrained_layout
* :ghissue:`18299`: New configure_subplots behaves badly on TkAgg backend
* :ghissue:`18300`: Remove the examples category "Our Favorite Recipes"
* :ghissue:`18077`: Imshow breaks if given a unyt_array input
* :ghissue:`7074`: Using a linestyle cycler with plt.errorbar results in strange plots
* :ghissue:`18236`: FuncAnimation fails to display with interval 0 on Tkagg backend
* :ghissue:`8107`:  invalid command name "..._on_timer" in FuncAnimation for (too) small interval
* :ghissue:`18272`: Add CI Interval to boxplot notch documentation
* :ghissue:`18137`: axhspan() in empty plots changes the xlimits of plots sharing the X axis
* :ghissue:`18246`: test_never_update is flaky
* :ghissue:`5856`: Horizontal stem plot
* :ghissue:`18160`: Add feature request template
* :ghissue:`17197`: Missing character upon savefig() with Free Serif font
* :ghissue:`17013`: Request: provide a contextmanager for ioff or allow plt.figure(draw_on_create=False)
* :ghissue:`17537`: hat graphs need an example...
* :ghissue:`17755`: mplot3d: add_collection3d issues
* :ghissue:`18192`: Cannot save SVG file with FIPS compliant Python
* :ghissue:`17574`: Vertical alignment of tick labels containing minus in font size other than 10 with usetex=True
* :ghissue:`18097`: Feature Request: Allow hexbin to use a string for parameter C to refer to column in data (DataFrame)
* :ghissue:`17689`: Add pause/resume methods to Animation baseclass
* :ghissue:`16087`: Error with greek letters in pdf export when using usetex=True and mathptmx
* :ghissue:`17136`: set_ticks() changes view limits of the axis
* :ghissue:`12198`: axvline incorrectly tries to handle unitized ymin, ymax
* :ghissue:`9139`: Python3 matplotlib 2.0.2 with Times New Roman misses unicode minus sign in pdf
* :ghissue:`5970`: pyplot.scatter raises obscure error when mistakenly passed a third string param
* :ghissue:`17936`: documentation and behavior do not match for suppressing (PDF) metadata
* :ghissue:`17932`: latex textrm does not work in Cairo backend
* :ghissue:`17714`: Universal fullscreen command
* :ghissue:`4584`: ColorbarBase draws edges in slightly wrong positions.
* :ghissue:`17878`: flipping of imshow in specgram
* :ghissue:`6118`: consider using qtpy for qt abstraction layer
* :ghissue:`17908`: rcParams restrictions on frame_formats are out of sync with supported values (HTMLWriter)
* :ghissue:`17867`: datetime plotting broken on master
* :ghissue:`16810`: Docs do not build in parallel
* :ghissue:`17918`: Extend hatch reference
* :ghissue:`17149`: Rasterization creates multiple bitmap elements and large file sizes
* :ghissue:`17855`: Add Hatch Example to gallery
* :ghissue:`15821`: Should constrained_layout work as plt.figure() argument?
* :ghissue:`15616`: Colormaps should have a ``_repr_html_`` that is an image of the colormap
* :ghissue:`17579`: ``BoundaryNorm`` yield a ``ZeroDivisionError: division by zero``
* :ghissue:`17652`: NEP 29 : Stop support for Python 3.6 soon ?
* :ghissue:`11095`: Repeated plot calls with xunits=None throws exception
* :ghissue:`17733`: Rename "array" (and perhaps "fields") section of Axes API
* :ghissue:`15610`: Link to most recent DevDocs when installing from Master Source
* :ghissue:`17817`: (documentation, possible first-timer bug) Typo and grammar on Legends and Annotations for tight layout guide page
* :ghissue:`17804`: Setting the norm on imshow object removes colorbar ylabel
* :ghissue:`17758`: bar, barh should take a list of hatches like it does of colors
* :ghissue:`17746`: Antialiasing with colorbars?
* :ghissue:`17659`: Enhancement: Set tick and ticklabel colors separately from matplotlib style file
* :ghissue:`17144`: Wrong icon on windows task bar for figure windows
* :ghissue:`2870`: Wrong symbols from a TrueType font
